diff options
| author | Claudius "keldu" Holeksa <mail@keldu.de> | 2026-07-27 13:32:05 +0200 |
|---|---|---|
| committer | Claudius "keldu" Holeksa <mail@keldu.de> | 2026-07-27 13:32:05 +0200 |
| commit | fb3a5f5bcba542974cf2f3f1f401ec717e662942 (patch) | |
| tree | 88426454fcbc370d53d0220f1ca5c70574afc968 /examples/poiseulle_particles_2d_gpu/step.hpp | |
| parent | 530bd236a0aee9c22b87de236164c59afe6adae7 (diff) | |
| download | libs-lbm-fb3a5f5bcba542974cf2f3f1f401ec717e662942.tar.gz | |
Cleaning up simulation setup
Diffstat (limited to 'examples/poiseulle_particles_2d_gpu/step.hpp')
| -rw-r--r-- | examples/poiseulle_particles_2d_gpu/step.hpp | 5 |
1 files changed, 3 insertions, 2 deletions
diff --git a/examples/poiseulle_particles_2d_gpu/step.hpp b/examples/poiseulle_particles_2d_gpu/step.hpp index aa0e382..c1b148f 100644 --- a/examples/poiseulle_particles_2d_gpu/step.hpp +++ b/examples/poiseulle_particles_2d_gpu/step.hpp @@ -18,13 +18,12 @@ saw::error_or<void> step( auto& info_f = fields.template get<"info">(); auto& porous_f = macros.template get<"porosity">(); - component<T,Desc,cmpt::HlbmParticle,encode::Sycl<saw::encode::Native>> particle; + // component<T,Desc,cmpt::HlbmOneParticle,encode::Sycl<saw::encode::Native>> particle; // auto coll_ev = q.submit([&](acpp::sycl::handler& h){ component<T,Desc,cmpt::Hlbm,encode::Sycl<saw::encode::Native>> collision{0.8}; component<T,Desc,cmpt::BounceBack,encode::Sycl<saw::encode::Native>> bb; - component<T,Desc,cmpt::AntiBounceBack<0u>,encode::Sycl<saw::encode::Native>> abb; saw::data<sch::Scalar<T>> rho_b; rho_b.at({}) = 1.0; @@ -77,11 +76,13 @@ saw::error_or<void> step( }); }).wait(); + /* q.submit([&](acpp::sycl::handler& h){ h.parallel_for(acpp::sycl::range<1u>{1u}, [=](acpp::sycl::id<1u> idx){ particle.apply(fields,macros,particles,{{0u}},t_i); }); }).wait(); + */ // Step /* |
